==> backup_download.php?file=website_backup_2025-05-04_05-55-00.zip: code/hk_cluster_code.php <==
<?php
/**
 * 香港站群页面数据处理文件
 * 查询region_id=2且tags包含23的产品，即香港地区的专区产品
 */

// 确保文件被包含而非直接访问
defined('INCLUDED_FROM_VIEW') or define('INCLUDED_FROM_VIEW', true);

// 引入数据库配置
require_once dirname(dirname(__FILE__)) . '/config/database.php';
// 引入网站配置
require_once dirname(__FILE__) . '/../public/config.php';

/**
 * 获取香港站群推荐产品
 * 查询条件：region_id=2（香港地区）且tags包含23（而不是8）
 *
 * @param bool $debug 是否开启调试模式打印数据
 * @return array 查询结果数组
 */
function getHkClusterProducts($debug = false) {
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句
        $query = "SELECT * FROM products 
                 WHERE region_id = 2 
                 AND FIND_IN_SET(23, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 计算记录数量
        $count = count($products);
        
        // 如果开启调试模式，打印查询结果
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>查询结果</h3>";
            echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
            
            if ($count > 0) {
                echo "<table border='1' cellpadding='5' cellspacing='0' style='border-collapse:collapse; width:100%;'>";
                echo "<tr style='background:#eee;'>";
                echo "<th>ID</th>";
                echo "<th>产品名称</th>";
                echo "<th>CPU</th>";
                echo "<th>内存</th>";
                echo "<th>硬盘</th>";
                echo "<th>带宽</th>";
                echo "<th>IP数量</th>";
                echo "<th>原价</th>";
                echo "<th>显示价格</th>";
                echo "<th>标签</th>";
                echo "</tr>";
                
                foreach ($products as $product) {
                    echo "<tr>";
                    echo "<td>" . $product['id'] . "</td>";
                    echo "<td>" . $product['name'] . "</td>";
                    echo "<td>" . $product['cpu'] . "</td>";
                    echo "<td>" . $product['memory'] . "</td>";
                    echo "<td>" . $product['disk'] . "</td>";
                    echo "<td>" . $product['bandwidth'] . "</td>";
                    echo "<td>" . $product['ip_count'] . "</td>";
                    echo "<td>$" . number_format($product['price'], 2) . "</td>";
                    echo "<td>$" . number_format($product['price'] * getMultiplier(), 2) . "</td>";
                    echo "<td>" . $product['tags'] . "</td>";
                    echo "</tr>";
                }
                
                echo "</table>";
            } else {
                echo "<p>没有找到匹配的记录</p>";
            }
            
            echo "<p>SQL: " . htmlspecialchars($query) . "</p>";
            echo "</div>";
        }
        
        // 处理产品数据
        foreach ($products as &$product) {
            // 计算显示价格（应用倍数）
            $product['display_price'] = $product['price'] * getMultiplier();
            
            // 格式化显示价格
            $product['formatted_price'] = number_format($product['display_price'], 2, '.', ',');
            
            // 处理标签
            if (!empty($product['tags'])) {
                $tagIds = explode(',', $product['tags']);
                $product['tag_names'] = getTagNames($db, $tagIds);
            } else {
                $product['tag_names'] = [];
            }
        }
        
        $result = $products;
    } catch (PDOException $e) {
        // 错误处理
        if ($debug) {
            echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
            echo "<h3>数据库错误</h3>";
            echo "<p>" . $e->getMessage() . "</p>";
            echo "</div>";
        }
        error_log("获取香港站群产品错误: " . $e->getMessage());
        $result = [];
    }
    
    return $result;
}

/**
 * 获取标签名称
 *
 * @param PDO $db 数据库连接
 * @param array $tagIds 标签ID数组
 * @return array 标签名称数组
 */
function getTagNames($db, $tagIds) {
    $tagNames = [];
    
    if (empty($tagIds)) {
        return $tagNames;
    }
    
    try {
        $placeholders = implode(',', array_fill(0, count($tagIds), '?'));
        $query = "SELECT id, name FROM tags WHERE id IN ($placeholders)";
        
        $stmt = $db->prepare($query);
        
        // 绑定参数
        foreach ($tagIds as $index => $id) {
            $stmt->bindValue($index + 1, $id);
        }
        
        $stmt->execute();
        
        while ($tag = $stmt->fetch()) {
            $tagNames[$tag['id']] = $tag['name'];
        }
    } catch (PDOException $e) {
        error_log("获取标签名称错误: " . $e->getMessage());
    }
    
    return $tagNames;
}

==> backup_download.php?file=website_backup_2025-05-06_06-33-27.zip: code/hk_cluster_code.php <==
<?php
/**
 * 香港站群页面数据处理文件
 * 查询region_id=2且tags包含23的产品，即香港地区的专区产品
 */

// 确保文件被包含而非直接访问
defined('INCLUDED_FROM_VIEW') or define('INCLUDED_FROM_VIEW', true);

// 引入数据库配置
require_once dirname(dirname(__FILE__)) . '/config/database.php';
// 引入网站配置
require_once dirname(__FILE__) . '/../public/config.php';

/**
 * 获取香港站群推荐产品
 * 查询条件：region_id=2（香港地区）且tags包含23（而不是8）
 *
 * @param bool $debug 是否开启调试模式打印数据
 * @return array 查询结果数组
 */
function getHkClusterProducts($debug = false) {
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句
        $query = "SELECT * FROM products 
                 WHERE region_id = 2 
                 AND FIND_IN_SET(23, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 计算记录数量
        $count = count($products);
        
        // 如果开启调试模式，打印查询结果
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>查询结果</h3>";
            echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
            
            if ($count > 0) {
                echo "<table border='1' cellpadding='5' cellspacing='0' style='border-collapse:collapse; width:100%;'>";
                echo "<tr style='background:#eee;'>";
                echo "<th>ID</th>";
                echo "<th>产品名称</th>";
                echo "<th>CPU</th>";
                echo "<th>内存</th>";
                echo "<th>硬盘</th>";
                echo "<th>带宽</th>";
                echo "<th>IP数量</th>";
                echo "<th>原价</th>";
                echo "<th>显示价格</th>";
                echo "<th>标签</th>";
                echo "</tr>";
                
                foreach ($products as $product) {
                    echo "<tr>";
                    echo "<td>" . $product['id'] . "</td>";
                    echo "<td>" . $product['name'] . "</td>";
                    echo "<td>" . $product['cpu'] . "</td>";
                    echo "<td>" . $product['memory'] . "</td>";
                    echo "<td>" . $product['disk'] . "</td>";
                    echo "<td>" . $product['bandwidth'] . "</td>";
                    echo "<td>" . $product['ip_count'] . "</td>";
                    echo "<td>$" . number_format($product['price'], 2) . "</td>";
                    echo "<td>$" . number_format($product['price'] * getMultiplier(), 2) . "</td>";
                    echo "<td>" . $product['tags'] . "</td>";
                    echo "</tr>";
                }
                
                echo "</table>";
            } else {
                echo "<p>没有找到匹配的记录</p>";
            }
            
            echo "<p>SQL: " . htmlspecialchars($query) . "</p>";
            echo "</div>";
        }
        
        // 处理产品数据
        foreach ($products as &$product) {
            // 计算显示价格（应用倍数）
            $product['display_price'] = $product['price'] * getMultiplier();
            
            // 格式化显示价格
            $product['formatted_price'] = number_format($product['display_price'], 2, '.', ',');
            
            // 处理标签
            if (!empty($product['tags'])) {
                $tagIds = explode(',', $product['tags']);
                $product['tag_names'] = getTagNames($db, $tagIds);
            } else {
                $product['tag_names'] = [];
            }
        }
        
        $result = $products;
    } catch (PDOException $e) {
        // 错误处理
        if ($debug) {
            echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
            echo "<h3>数据库错误</h3>";
            echo "<p><strong>错误信息:</strong> " . $e->getMessage() . "</p>";
            echo "<p><strong>SQL查询:</strong> " . htmlspecialchars($query) . "</p>";
            echo "<p><strong>错误代码:</strong> " . $e->getCode() . "</p>";
            echo "<p><strong>错误文件:</strong> " . $e->getFile() . " (行 " . $e->getLine() . ")</p>";
            echo "</div>";
        }
        error_log("获取香港站群产品错误: " . $e->getMessage());
        $result = [];
    }
    
    return $result;
}

/**
 * 获取标签名称
 *
 * @param PDO $db 数据库连接
 * @param array $tagIds 标签ID数组
 * @return array 标签名称数组
 */
function getTagNames($db, $tagIds) {
    $tagNames = [];
    
    if (empty($tagIds)) {
        return $tagNames;
    }
    
    try {
        $placeholders = implode(',', array_fill(0, count($tagIds), '?'));
        $query = "SELECT id, name FROM tags WHERE id IN ($placeholders)";
        
        $stmt = $db->prepare($query);
        
        // 绑定参数
        foreach ($tagIds as $index => $id) {
            $stmt->bindValue($index + 1, $id);
        }
        
        $stmt->execute();
        
        while ($tag = $stmt->fetch()) {
            $tagNames[$tag['id']] = $tag['name'];
        }
    } catch (PDOException $e) {
        error_log("获取标签名称错误: " . $e->getMessage());
    }
    
    return $tagNames;
}

/**
 * 获取同时包含标签23和19的产品
 * 不需要region_id作为判断条件
 *
 * @param bool $debug 是否开启调试模式打印数据
 * @return array 查询结果数组
 */
function getSpecialTagsProducts($debug = false) {
    $db = getDbConnection();
    $result = [];
    
    try {
        // 使用简单的LIKE查询 - 已验证可以找到3条记录
        $query = "SELECT * FROM products 
                 WHERE region_id = 2
                 AND tags LIKE '%23%'
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 计算记录数量
        $count = count($products);
        
        // 如果开启调试模式，打印查询结果
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>查询结果</h3>";
            echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
            
            if ($count > 0) {
                echo "<table border='1' cellpadding='5' cellspacing='0' style='border-collapse:collapse; width:100%;'>";
                echo "<tr style='background:#eee;'>";
                echo "<th>ID</th>";
                echo "<th>CPU</th>";
                echo "<th>内存</th>";
                echo "<th>硬盘</th>";
                echo "<th>带宽</th>";
                echo "<th>IP数量</th>";
                echo "<th>原价</th>";
                echo "<th>显示价格</th>";
                echo "<th>标签</th>";
                echo "</tr>";
                
                foreach ($products as $product) {
                    echo "<tr>";
                    echo "<td>" . $product['id'] . "</td>";
                    echo "<td>" . $product['cpu'] . "</td>";
                    echo "<td>" . $product['memory'] . "</td>";
                    echo "<td>" . $product['disk'] . "</td>";
                    echo "<td>" . $product['bandwidth'] . "</td>";
                    echo "<td>" . $product['ip_count'] . "</td>";
                    echo "<td>$" . number_format($product['price'], 2) . "</td>";
                    echo "<td>$" . number_format($product['price'] * getMultiplier(), 2) . "</td>";
                    echo "<td>" . $product['tags'] . "</td>";
                    echo "</tr>";
                }
                
                echo "</table>";
            } else {
                echo "<p>没有找到匹配的记录</p>";
            }
            
            echo "<p>SQL: " . htmlspecialchars($query) . "</p>";
            echo "</div>";
        }
        
        // 处理产品数据
        foreach ($products as &$product) {
            // 计算显示价格（应用倍数）
            $product['display_price'] = $product['price'] * getMultiplier();
            
            // 格式化显示价格
            $product['formatted_price'] = number_format($product['display_price'], 2, '.', ',');
            
            // 处理标签
            if (!empty($product['tags'])) {
                $tagIds = explode(',', $product['tags']);
                $product['tag_names'] = getTagNames($db, $tagIds);
            } else {
                $product['tag_names'] = [];
            }
        }
        
        $result = $products;
    } catch (PDOException $e) {
        // 错误处理
        if ($debug) {
            echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
            echo "<h3>数据库错误</h3>";
            echo "<p><strong>错误信息:</strong> " . $e->getMessage() . "</p>";
            echo "<p><strong>SQL查询:</strong> " . htmlspecialchars($query) . "</p>";
            echo "<p><strong>错误代码:</strong> " . $e->getCode() . "</p>";
            echo "<p><strong>错误文件:</strong> " . $e->getFile() . " (行 " . $e->getLine() . ")</p>";
            echo "</div>";
        }
        error_log("获取特殊标签产品错误: " . $e->getMessage());
        $result = [];
    }
    
    return $result;
}
